@@ -1,21 +1,23 @@
 """Tests for google calendar API library."""
 
 import datetime
-from unittest.mock import ANY, Mock, call
+from collections.abc import Awaitable, Callable
 
 from freezegun import freeze_time
+
 from gcal_sync.api import GoogleCalendarService, ListEventsRequest
 from gcal_sync.model import Calendar, DateOrDatetime, Event
 
-from .conftest import ApiResult
+from .conftest import ApiRequest, ApiResult
 
 
 async def test_list_calendars(
-    calendar_service: GoogleCalendarService, calendars_list: ApiResult
+    calendar_service_cb: Callable[[], Awaitable[GoogleCalendarService]],
+    json_response: ApiResult,
 ) -> None:
     """Test list calendars API."""
 
-    calendars_list(
+    json_response(
         {
             "items": [
                 {
@@ -29,7 +31,7 @@ async def test_list_calendars(
             ]
         }
     )
-
+    calendar_service = await calendar_service_cb()
     result = await calendar_service.async_list_calendars()
     assert result.items == [
         Calendar(id="calendar-id-1", summary="Calendar 1"),
@@ -38,70 +40,66 @@ async def test_list_calendars(
 
 
 async def test_list_calendars_empty_reply(
-    calendar_service: GoogleCalendarService, calendars_list: ApiResult
+    calendar_service_cb: Callable[[], Awaitable[GoogleCalendarService]],
+    json_response: ApiResult,
 ) -> None:
     """Test list calendars API."""
 
-    calendars_list({})
+    json_response({})
 
+    calendar_service = await calendar_service_cb()
     result = await calendar_service.async_list_calendars()
     assert result.items == []
 
 
 @freeze_time("2022-04-30 07:31:02", tz_offset=-6)
 async def test_list_events(
-    calendar_service: GoogleCalendarService,
-    events_list: Mock,
+    calendar_service_cb: Callable[[], Awaitable[GoogleCalendarService]],
+    json_response: ApiResult,
+    url_request: Callable[[], str],
 ) -> None:
     """Test list calendars API."""
 
-    events_list.return_value.execute.return_value = {
-        "items": [
-            {
-                "id": "some-event-id-1",
-                "summary": "Event 1",
-                "description": "Event description 1",
-                "start": {
-                    "date": "2022-04-13",
+    json_response(
+        {
+            "items": [
+                {
+                    "id": "some-event-id-1",
+                    "summary": "Event 1",
+                    "description": "Event description 1",
+                    "start": {
+                        "date": "2022-04-13",
+                    },
+                    "end": {
+                        "date": "2022-04-14",
+                    },
+                    "status": "confirmed",
+                    "transparency": "transparent",
                 },
-                "end": {
-                    "date": "2022-04-14",
+                {
+                    "id": "some-event-id-2",
+                    "summary": "Event 2",
+                    "description": "Event description 2",
+                    "start": {
+                        "date": "2022-04-14",
+                    },
+                    "end": {
+                        "date": "2022-04-20",
+                    },
+                    "transparency": "opaque",
                 },
-                "status": "confirmed",
-                "transparency": "transparent",
-            },
-            {
-                "id": "some-event-id-2",
-                "summary": "Event 2",
-                "description": "Event description 2",
-                "start": {
-                    "date": "2022-04-14",
-                },
-                "end": {
-                    "date": "2022-04-20",
-                },
-                "transparency": "opaque",
-            },
-        ]
-    }
+            ]
+        }
+    )
+    calendar_service = await calendar_service_cb()
     result = await calendar_service.async_list_events(
         ListEventsRequest(calendar_id="some-calendar-id")
     )
-    events_list.assert_called()
-    calls = events_list.mock_calls
-    assert len(calls) == 2  # API call and execute call
-    events_list.assert_has_calls(
-        [
-            call(
-                calendarId="some-calendar-id",
-                timeMin="2022-04-30T01:31:02+00:00",
-                maxResults=100,
-                singleEvents=True,
-                orderBy="startTime",
-                fields=ANY,
-            )
-        ]
-    )
+    assert url_request() == [
+        "/calendars/some-calendar-id/events?maxResult=100&singleEvents=true&orderBy=startTime"
+        "&fields=kind,nextPageToken,nextSyncToken,items(id,summary,description,location,start"
+        ",end,transparency)&timeMin=2022-04-30T01:31:02%2B00:00"
+    ]
     assert result.items == [
         Event(
             id="some-event-id-1",
@@ -125,41 +123,35 @@ async def test_list_events(
 
 
 async def test_list_events_with_date_limit(
-    calendar_service: GoogleCalendarService,
-    events_list: Mock,
+    calendar_service_cb: Callable[[], Awaitable[GoogleCalendarService]],
+    json_response: ApiResult,
+    url_request: Callable[[], str],
 ) -> None:
     """Test list calendars API with start/end datetimes."""
 
     # Test doesn't care about response
-    events_list.return_value.execute.return_value = {"items": []}
+    json_response({"items": []})
 
     tzinfo = datetime.timezone(datetime.timedelta(hours=-6), "America/Regina")
     start = datetime.datetime(2022, 4, 13, 7, 30, 12, 345678, tzinfo)
     end = datetime.datetime(2022, 4, 13, 9, 30, 12, 345678, tzinfo)
 
+    calendar_service = await calendar_service_cb()
     await calendar_service.async_list_events(
-        ListEventsRequest(calendar_id="some-calendar-id", start_time=start, end_time=end),
-    )
-    events_list.assert_called()
-    calls = events_list.mock_calls
-    assert len(calls) == 2  # API call and execute call
-    events_list.assert_has_calls(
-        [
-            call(
-                calendarId="some-calendar-id",
-                timeMin="2022-04-13T07:30:12-06:00",
-                timeMax="2022-04-13T09:30:12-06:00",
-                maxResults=100,
-                singleEvents=True,
-                orderBy="startTime",
-                fields=ANY,
-            )
-        ]
+        ListEventsRequest(
+            calendar_id="some-calendar-id", start_time=start, end_time=end
+        ),
     )
+    assert url_request() == [
+        "/calendars/some-calendar-id/events?maxResult=100&singleEvents=true&orderBy=startTime"
+        "&fields=kind,nextPageToken,nextSyncToken,items(id,summary,description,location,start,"
+        "end,transparency)&timeMin=2022-04-13T07:30:12-06:00&timeMax=2022-04-13T09:30:12-06:00"
+    ]
 
 
 async def test_create_event_with_date(
-    calendar_service: GoogleCalendarService, insert_event: Mock
+    calendar_service_cb: Callable[[], Awaitable[GoogleCalendarService]],
+    json_request: ApiRequest,
 ) -> None:
     """Test create event API."""
 
@@ -173,21 +165,21 @@ async def test_create_event_with_date(
         end=DateOrDatetime(date=end_date),
     )
 
+    calendar_service = await calendar_service_cb()
     await calendar_service.async_create_event("calendar-id", event)
-    insert_event.assert_called()
-    assert insert_event.mock_calls[0] == call(
-        calendarId="calendar-id",
-        body={
+    assert json_request() == [
+        {
             "summary": "Summary",
             "description": "Description",
             "start": {"date": "2022-04-15"},
             "end": {"date": "2022-04-17"},
-        },
-    )
+        }
+    ]
 
 
 async def test_create_event_with_datetime(
-    calendar_service: GoogleCalendarService, insert_event: Mock
+    calendar_service_cb: Callable[[], Awaitable[GoogleCalendarService]],
+    json_request: ApiRequest,
 ) -> None:
     """Test create event API with date times."""
 
@@ -201,22 +193,22 @@ async def test_create_event_with_datetime(
         end=DateOrDatetime(date_time=end),
     )
 
+    calendar_service = await calendar_service_cb()
     await calendar_service.async_create_event("calendar-id", event)
-    insert_event.assert_called()
-    assert insert_event.mock_calls[0] == call(
-        calendarId="calendar-id",
-        body={
+    assert json_request() == [
+        {
             "summary": "Summary",
             "description": "Description",
             # micros are stripped
             "start": {"dateTime": "2022-04-15T07:30:12"},
             "end": {"dateTime": "2022-04-15T09:30:12"},
-        },
-    )
+        }
+    ]
 
 
 async def test_create_event_with_timezone(
-    calendar_service: GoogleCalendarService, insert_event: Mock
+    calendar_service_cb: Callable[[], Awaitable[GoogleCalendarService]],
+    json_request: ApiRequest,
 ) -> None:
     """Test create event API with date times."""
 
@@ -237,42 +229,44 @@ async def test_create_event_with_timezone(
         end=DateOrDatetime(date_time=end),
     )
 
+    calendar_service = await calendar_service_cb()
     await calendar_service.async_create_event("calendar-id", event)
-    insert_event.assert_called()
-    assert insert_event.mock_calls[0] == call(
-        calendarId="calendar-id",
-        body={
+    assert json_request() == [
+        {
             "summary": "Summary",
             "description": "Description",
             "start": {"dateTime": "2022-04-15T07:30:00-06:00"},
             "end": {"dateTime": "2022-04-15T09:30:00-06:00"},
-        },
-    )
+        }
+    ]
 
 
 async def test_event_missing_summary(
-    calendar_service: GoogleCalendarService,
-    events_list: Mock,
+    calendar_service_cb: Callable[[], Awaitable[GoogleCalendarService]],
+    json_response: ApiResult,
 ) -> None:
     """Test list calendars API."""
 
-    events_list.return_value.execute.return_value = {
-        "items": [
-            {
-                "id": "some-event-id-1",
-                "description": "Event description 1",
-                "start": {
-                    "date": "2022-04-13",
+    json_response(
+        {
+            "items": [
+                {
+                    "id": "some-event-id-1",
+                    "description": "Event description 1",
+                    "start": {
+                        "date": "2022-04-13",
+                    },
+                    "end": {
+                        "date": "2022-04-14",
+                    },
+                    "status": "confirmed",
+                    "transparency": "transparent",
                 },
-                "end": {
-                    "date": "2022-04-14",
-                },
-                "status": "confirmed",
-                "transparency": "transparent",
-            },
-        ]
-    }
+            ]
+        }
+    )
 
+    calendar_service = await calendar_service_cb()
     result = await calendar_service.async_list_events(
         ListEventsRequest(calendar_id="some-calendar-id")
     )
@@ -289,29 +283,32 @@ async def test_event_missing_summary(
 
 
 async def test_list_events_page_token(
-    calendar_service: GoogleCalendarService,
-    events_list: Mock,
+    calendar_service_cb: Callable[[], Awaitable[GoogleCalendarService]],
+    json_response: ApiResult,
 ) -> None:
     """Test list calendars API."""
 
-    events_list.return_value.execute.return_value = {
-        "nextPageToken": "some-token",
-        "items": [
-            {
-                "id": "some-event-id-1",
-                "summary": "Event 1",
-                "description": "Event description 1",
-                "start": {
-                    "date": "2022-04-13",
+    json_response(
+        {
+            "nextPageToken": "some-token",
+            "items": [
+                {
+                    "id": "some-event-id-1",
+                    "summary": "Event 1",
+                    "description": "Event description 1",
+                    "start": {
+                        "date": "2022-04-13",
+                    },
+                    "end": {
+                        "date": "2022-04-14",
+                    },
+                    "status": "confirmed",
+                    "transparency": "transparent",
                 },
-                "end": {
-                    "date": "2022-04-14",
-                },
-                "status": "confirmed",
-                "transparency": "transparent",
-            },
-        ]
-    }
+            ],
+        }
+    )
+    calendar_service = await calendar_service_cb()
     result = await calendar_service.async_list_events(
         ListEventsRequest(calendar_id="some-calendar-id")
     )
